built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;WinExtras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;Positioning;Location;Qml;Quick;QuickWidgets;Scxml;Script;ScriptTools;Sensors;TextToSpeech;Charts;Svg;DataVisualization;UiTools;AxContainer;WebChannel;WebEngineCore;WebEngine;WebEngineWidgets;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
    .split(";"))

shiboken_library_soversion = str(5.9)
pyside_library_soversion = str(5.9)

version = "5.9.0~a1"
version_info = (5, 9, 0, "a", 1)

__build_date__ = '2019-05-29T14:46:09+00:00'
__build_commit_date__ = '2018-07-09T09:38:01+00:00'
__build_commit_hash__ = '7a228f9f4a0c16fbfb77c013f0e74f552489b4bb'
__build_commit_hash_described__ = 'maya1-532-g7a228f9f4'

# Timestamp used for snapshot build, which is part of snapshot package version.
__setup_py_package_timestamp__ = ''
